=== modified file 'NEWS'
--- NEWS	2009-04-03 22:30:59 +0000
+++ NEWS	2009-04-03 23:18:11 +0000
@@ -187,7 +187,7 @@
 API Changes
 ***********
 
-* APIs deprecated in 1.6 and previous verisons of bzr are now removed.
+* APIs deprecated in 1.6 and previous versions of bzr are now removed.
   (Martin Pool)
 
 * ``CommitReporter`` is no longer called with ``unchanged`` status during
@@ -215,6 +215,9 @@
 * The ``pb`` argument to ``fetch()`` is deprecated.
   (Martin Pool)
 
+* The ``Serializer`` class and the serializer ``format registry`` have moved
+  from ``bzrlib.xml_serializer`` to ``bzrlib.serializer``. (Jelmer Vernooij)
+
 * The smart server jail now hooks into BzrDir.open to prevent any BzrDir
   that is not inside the backing transport from being opened.  See the
   module documentation for ``bzrlib.smart.request`` for details.

=== modified file 'bzrlib/bundle/serializer/v4.py'
--- bzrlib/bundle/serializer/v4.py	2009-03-25 23:15:11 +0000
+++ bzrlib/bundle/serializer/v4.py	2009-04-02 15:28:11 +0000
@@ -27,9 +27,9 @@
     pack,
     revision as _mod_revision,
     trace,
-    xml_serializer,
+    serializer,
     )
-from bzrlib.bundle import bundle_data, serializer
+from bzrlib.bundle import bundle_data, serializer as bundle_serializer
 from bzrlib.util import bencode
 
 
@@ -54,8 +54,8 @@
 
     def begin(self):
         """Start writing the bundle"""
-        self._fileobj.write(serializer._get_bundle_header(
-            serializer.v4_string))
+        self._fileobj.write(bundle_serializer._get_bundle_header(
+            bundle_serializer.v4_string))
         self._fileobj.write('#\n')
         self._container.begin()
 
@@ -218,7 +218,7 @@
             yield (bytes, metadata) + self.decode_name(names[0][0])
 
 
-class BundleSerializerV4(serializer.BundleSerializer):
+class BundleSerializerV4(bundle_serializer.BundleSerializer):
     """Implement the high-level bundle interface"""
 
     def write(self, repository, revision_ids, forced_bases, fileobj):
@@ -250,7 +250,7 @@
     @staticmethod
     def get_source_serializer(info):
         """Retrieve the serializer for a given info object"""
-        return xml_serializer.format_registry.get(info['serializer'])
+        return serializer.format_registry.get(info['serializer'])
 
 
 class BundleWriteOperation(object):

=== added file 'bzrlib/serializer.py'
--- bzrlib/serializer.py	1970-01-01 00:00:00 +0000
+++ bzrlib/serializer.py	2009-04-03 21:50:40 +0000
@@ -0,0 +1,77 @@
+# Copyright (C) 2005, 2006, 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+
+"""Inventory/revision serialization."""
+
+
+from bzrlib import registry
+
+
+class Serializer(object):
+    """Inventory and revision serialization/deserialization."""
+
+    def write_inventory(self, inv, f):
+        """Write inventory to a file"""
+        raise NotImplementedError(self.write_inventory)
+
+    def write_inventory_to_string(self, inv):
+        raise NotImplementedError(self.write_inventory_to_string)
+
+    def read_inventory_from_string(self, string, revision_id=None,
+                                   entry_cache=None):
+        """Read string into an inventory object.
+
+        :param string: The serialized inventory to read.
+        :param revision_id: If not-None, the expected revision id of the
+            inventory. Some serialisers use this to set the results' root
+            revision. This should be supplied for deserialising all
+            from-repository inventories so that xml5 inventories that were
+            serialised without a revision identifier can be given the right
+            revision id (but not for working tree inventories where users can
+            edit the data without triggering checksum errors or anything).
+        :param entry_cache: An optional cache of InventoryEntry objects. If
+            supplied we will look up entries via (file_id, revision_id) which
+            should map to a valid InventoryEntry (File/Directory/etc) object.
+        """
+        raise NotImplementedError(self.read_inventory_from_string)
+
+    def read_inventory(self, f, revision_id=None):
+        raise NotImplementedError(self.read_inventory)
+
+    def write_revision(self, rev, f):
+        raise NotImplementedError(self.write_revision)
+
+    def write_revision_to_string(self, rev):
+        raise NotImplementedError(self.write_revision_to_string)
+
+    def read_revision(self, f):
+        raise NotImplementedError(self.read_revision)
+
+    def read_revision_from_string(self, xml_string):
+        raise NotImplementedError(self.read_revision_from_string)
+
+
+class SerializerRegistry(registry.Registry):
+    """Registry for serializer objects"""
+
+
+format_registry = SerializerRegistry()
+format_registry.register_lazy('4', 'bzrlib.xml4', 'serializer_v4')
+format_registry.register_lazy('5', 'bzrlib.xml5', 'serializer_v5')
+format_registry.register_lazy('6', 'bzrlib.xml6', 'serializer_v6')
+format_registry.register_lazy('7', 'bzrlib.xml7', 'serializer_v7')
+format_registry.register_lazy('8', 'bzrlib.xml8', 'serializer_v8')

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2009-04-03 15:32:56 +0000
+++ bzrlib/tests/__init__.py	2009-04-03 23:18:11 +0000
@@ -3374,6 +3374,7 @@
                    'bzrlib.tests.test_rules',
                    'bzrlib.tests.test_sampler',
                    'bzrlib.tests.test_selftest',
+                   'bzrlib.tests.test_serializer',
                    'bzrlib.tests.test_setup',
                    'bzrlib.tests.test_sftp_transport',
                    'bzrlib.tests.test_shelf',

=== added file 'bzrlib/tests/test_serializer.py'
--- bzrlib/tests/test_serializer.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_serializer.py	2009-04-03 21:50:40 +0000
@@ -0,0 +1,45 @@
+# Copyright (C) 2005 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+
+"""Tests for the revision/inventory Serializers."""
+
+
+from bzrlib import (
+    serializer,
+    xml4,
+    xml5,
+    xml6,
+    xml7,
+    xml8,
+    )
+from bzrlib.tests import TestCase
+
+
+class TestSerializer(TestCase):
+    """Test serializer"""
+
+    def test_registry(self):
+        self.assertIs(xml4.serializer_v4,
+                      serializer.format_registry.get('4'))
+        self.assertIs(xml5.serializer_v5,
+                      serializer.format_registry.get('5'))
+        self.assertIs(xml6.serializer_v6,
+                      serializer.format_registry.get('6'))
+        self.assertIs(xml7.serializer_v7,
+                      serializer.format_registry.get('7'))
+        self.assertIs(xml8.serializer_v8,
+                      serializer.format_registry.get('8'))

=== modified file 'bzrlib/tests/test_xml.py'
--- bzrlib/tests/test_xml.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_xml.py	2009-04-03 21:50:40 +0000
@@ -21,7 +21,7 @@
     inventory,
     xml7,
     xml8,
-    xml_serializer,
+    serializer,
     )
 from bzrlib.tests import TestCase
 from bzrlib.inventory import Inventory, InventoryEntry
@@ -492,18 +492,6 @@
 
         self.assertEqual(len(expected), len(actual))
 
-    def test_registry(self):
-        self.assertIs(serializer_v4,
-                      xml_serializer.format_registry.get('4'))
-        self.assertIs(bzrlib.xml5.serializer_v5,
-                      xml_serializer.format_registry.get('5'))
-        self.assertIs(bzrlib.xml6.serializer_v6,
-                      xml_serializer.format_registry.get('6'))
-        self.assertIs(bzrlib.xml7.serializer_v7,
-                      xml_serializer.format_registry.get('7'))
-        self.assertIs(bzrlib.xml8.serializer_v8,
-                      xml_serializer.format_registry.get('8'))
-
 
 class TestEncodeAndEscape(TestCase):
     """Whitebox testing of the _encode_and_escape function."""

=== modified file 'bzrlib/xml4.py'
--- bzrlib/xml4.py	2009-03-23 14:59:43 +0000
+++ bzrlib/xml4.py	2009-04-02 15:28:11 +0000
@@ -14,14 +14,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from bzrlib.xml_serializer import ElementTree, SubElement, Element, Serializer
+from bzrlib.xml_serializer import (
+    Element,
+    ElementTree,
+    SubElement,
+    XMLSerializer,
+    )
 from bzrlib.inventory import ROOT_ID, Inventory, InventoryEntry
 import bzrlib.inventory as inventory
 from bzrlib.revision import Revision
 from bzrlib.errors import BzrError
 
 
-class _Serializer_v4(Serializer):
+class _Serializer_v4(XMLSerializer):
     """Version 0.0.4 serializer
 
     You should use the serializer_v4 singleton.

=== modified file 'bzrlib/xml8.py'
--- bzrlib/xml8.py	2009-03-23 14:59:43 +0000
+++ bzrlib/xml8.py	2009-04-02 15:28:11 +0000
@@ -24,7 +24,11 @@
     revision as _mod_revision,
     trace,
     )
-from bzrlib.xml_serializer import SubElement, Element, Serializer
+from bzrlib.xml_serializer import (
+    Element,
+    SubElement,
+    XMLSerializer,
+    )
 from bzrlib.inventory import ROOT_ID, Inventory, InventoryEntry
 from bzrlib.revision import Revision
 from bzrlib.errors import BzrError
@@ -139,7 +143,7 @@
     _to_escaped_map.clear()
 
 
-class Serializer_v8(Serializer):
+class Serializer_v8(XMLSerializer):
     """This serialiser adds rich roots.
 
     Its revision format number matches its inventory number.

=== modified file 'bzrlib/xml_serializer.py'
--- bzrlib/xml_serializer.py	2009-03-31 20:34:33 +0000
+++ bzrlib/xml_serializer.py	2009-04-03 23:18:11 +0000
@@ -22,7 +22,7 @@
 # importing this module is fairly slow because it has to load several
 # ElementTree bits
 
-from bzrlib import registry
+from bzrlib.serializer import Serializer
 from bzrlib.trace import mutter, warning
 
 try:
@@ -49,15 +49,8 @@
 from bzrlib import errors
 
 
-class Serializer(object):
-    """Abstract object serialize/deserialize"""
-
-    def write_inventory(self, inv, f):
-        """Write inventory to a file"""
-        raise NotImplementedError(self.write_inventory)
-
-    def write_inventory_to_string(self, inv):
-        raise NotImplementedError(self.write_inventory_to_string)
+class XMLSerializer(Serializer):
+    """Abstract XML object serialize/deserialize"""
 
     def read_inventory_from_string(self, xml_string, revision_id=None,
                                    entry_cache=None):
@@ -175,18 +168,6 @@
 elementtree.ElementTree._escape_cdata = _escape_cdata
 
 
-class SerializerRegistry(registry.Registry):
-    """Registry for serializer objects"""
-
-
-format_registry = SerializerRegistry()
-format_registry.register_lazy('4', 'bzrlib.xml4', 'serializer_v4')
-format_registry.register_lazy('5', 'bzrlib.xml5', 'serializer_v5')
-format_registry.register_lazy('6', 'bzrlib.xml6', 'serializer_v6')
-format_registry.register_lazy('7', 'bzrlib.xml7', 'serializer_v7')
-format_registry.register_lazy('8', 'bzrlib.xml8', 'serializer_v8')
-
-
 def escape_invalid_chars(message):
     """Escape the XML-invalid characters in a commit message.
 
@@ -200,4 +181,3 @@
     return re.subn(u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]+',
             lambda match: match.group(0).encode('unicode_escape'),
             message)
-

